
# 202321012 - reverse 프로젝트

## 개요

reverse는 역순 프로그램으로 지정된 입력 파일에서 데이터를 읽어 역순으로 만드는 것이다. 

## 주요기능

- 입력: 프로그램이 데이터를 읽어들이는 것
- 출력: 프로그램이 데이터를 출력하는 것
- 반전: 주어진 데이터를 반전시키는 것
- 오류: 오류 메세지를 출력하는 것
- 리디렉션: 츠로그램의 입력 또는 출력을 파일이나 다른 프로그램으로 재지정하는 것 
- 연결 리스트: 각 요소가 다음 요소에 대한 참조를 포함하는 선형 데이터 구조
- 역순: 항목의 순서를 거꾸로 바꾸는 것 

## 사용기술

- fopen(), getline(), fclose(): 입력파일을 읽고 출력하는 코드를 작성하는 언어
- fprintf(): 화면에 출력하기 위한 언어
- fgets(): 파일에서 한 줄씩 읽어드리는 언어
- append(): 연결 리스트에 추가하는 언어
- printReverse(): 재귀를 사용하여 연결 리스트에 역순으로 출력하는 언어

## 진행계획

- 요구 사항 분석: 어떤 종류의 데이터를 역순으로 처리할지, 어떤 방식으로 구현할지 등을 분석한다.
- 구현 환경 설정: 필요한 프로그래밍 언어나 도구를 선택하고 설정한다. 
- 알고리즘 설계: 선택한 데이터 구조나 문제의 특성에 맞는 알고리즘을 설계한다.
- 코드구현: 설게한 알고리즘을 바탕으로 코드를 구현한다. 
- 테스트: 작성한 코드를 테스트하여 정확성과 성능을 확인합니다. 
- 최적화: 필요한 경우 코드의 성능을 향상시키기 위해 최적화 작업을 수행합니다. 
